package
Version:
v0.0.0-...-8a31c25
Opens a new window with list of versions in this module.
Published: Sep 8, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Client interface {
PushRaw(serviceID string, data []byte) (err error)
}
Client ...
Source Files
¶
Click to show internal directories.
Click to hide internal directories.